# Asset for daily thermal anomalies predictions

This asset allows to start an application that contains the pipeline
for the daily prediction of thermal anomalies.  
The pipeline is scheduled every day according to the latency of the input data on the Copernicus services (25 days).

It is possible to monitor the status of each pipeline by means of a web console
available once the application is up and running.
In the following, we will describe in details all the steps needed to start the application
and to open the web application to trigger each pipeline, monitor their status and debug their results.

## Asset modules

Within the (unzipped) folder there are the following files:
1. the folder `logs` containing the logs of every run of both pipelines
2. the folder `plugins` which is empty and only needed if a new plugin for the pipeline orchestrator is installed
3. the utils file `custom_sudoers` needed by the Docker engine when the application starts
4. the file `requirements.txt` that contains the complete list of python dependencies needed by the application to properly run
5. the file `Dockerfile` which contains specific instructions needed by the Docker engine to build the image
6. the file `docker-compose.yaml` that manages and orchestrates all the containers included in the application
7. the tar archive `asset-pl-base` that contains a Docker filesystem needed by the application to start 
8. this README

## Start
### RequirPements

Requirements to start the application
- [Docker](https://docs.docker.com/)

### Modis credentials

In order to be able to run the pipeline and correctly retrieve MODIS data (in particular historical thermal anomalies data),
it will be necessary to have a NASA Earth Data account ([link](https://urs.earthdata.nasa.gov/) for the registration)
and put the credentials into the `docker-compose.yml` file, following this example
```shell
    AIRFLOW_VAR_MODIS_USERNAME: ${MODIS_USERNAME:-your-username}
    AIRFLOW_VAR_MODIS_PASSWORD: ${MODIS_PASSWORD:-your-password}
```

## GCP account

Since the data is also stored (both datasets and predictions) in a private Google Cloud bucket, we recommend to
contact us to get a custom service account that will allow you to correctly access the data and run the pipeline.

Please send an e-mail to `team.turing@stamtech.com`.


### Installation

After downloading the zipped asset folder, please unzip it, put it into a known location and go into the 
(unzipped) folder.
After opening a terminal, by means of the command `ls` you will be able to explore the content of the asset folder
and check that all the modules listed in the previous section are present.
To begin with, please digit the command

```shell
 docker import ./asset-pl-base.tar base:latest  
```

This will import the tar archive `asset-pl-base` and create a Docker image needed by the application under the name `base`.
Now, in order to start the application, you simply need to write the command

```shell
 docker compose up  
```

This will instruct the Docker engine to pull all the Docker images needed by the application and to start the application.
It will take some minutes before all the containers will run. The application will be up and running once you will see on the logs 
printed something like

```shell
  pipelines-airflow-webserver-1  | 127.0.0.1 - - [31/Aug/2023:14:14:43 +0000] "GET /health HTTP/1.1" 200 141 "-" "curl/7.74.0"
```

The web application will be available on the local address 

```shell
localhost:8090
```

If you open this page with your preferred browser, you will be asked to login. 
The default access credentials are 

```shell
USER: airflow
PASSWORD: airflow
```

Of course these credentials can be customized through specific environment variable, that can be configured
in the file `docker-compose.yaml` and called `AIRFLOW_WWW_AIRFLOW_USER` and `AIRFLOW_WWW_AIRFLOW_PSW`.

Once you have logged in, then you will have available a user-friendly graphical interface
that will allow us to trigger new run of the pipelines and monitor the status of each run.

## Created with

- [Python](https://www.python.org/)
- [Airflow](https://airflow.apache.org/)
- [Docker](https://docs.docker.com/)

